## Formål ♻️
I `dvh-tools` eksisterer alle klasser og funksjoner samlet til gjenbruk slik at de er tilgjenglig for andre prosjekter.

---

### Beskrivelse 🌳
Pakken inneholder funksjoner for å lese og skrice data til og fra Oracle database, samt funksjoner for å jobbe med Google Cloud.
Strukturen er som følger:
- oracle (inneholder operasjoner for det som måtte angå av database funksjonalitet)
- cloud_functions (all operasjoner for å implementere kobling med google cloud) 
- data_operations (diverse funksjoner for ulike operasjoner)

---

## Installasjon 💻
Du kan installere pakken ved å bruke `pip` kommando:

```shell
pip install git+https://github.com/navikt/dvh_tools.git
```
